@@ -1,6 +1,6 @@
 from re import compile
 
-from ..constants import Constants as MainConstants
+from ..constants import Constants as ScorerConstants
 
 
 class Patterns:
@@ -10,4 +10,4 @@ class Patterns:
 
 
 class Constants:
-    NODE_MODULES_FRAGMENT = MainConstants.PATH_DELIMITER + "node_modules" + MainConstants.PATH_DELIMITER
+    NODE_MODULES_FRAGMENT = ScorerConstants.PATH_DELIMITER + "node_modules" + ScorerConstants.PATH_DELIMITER
